<%@include file="include/header.jsp"%>
<%!
//-----------------------------------------------
void insert(AzureDao dao){
	AzureData data = new AzureData();
	data.domain = paramString("domain");
	data.azClientId = paramString("azClientId");
	data.azClientSecret = paramString("azClientSecret");
	data.azTenantId = paramString("azTenantId");
	data.period = paramInt("period");

	// Param validation.
	if (isEmpty(data.domain)) {
		errList.add(translate("Domain missing."));
		return;
	}

	if (isEmpty(data.azClientId)) {
		errList.add(translate("Application ID missing."));
		return;
	}

	if (isEmpty(data.azTenantId)) {
		errList.add(translate("Directory ID missing."));
		return;
	}

	if (isEmpty(data.azClientSecret)) {
		errList.add(translate("Client Secret missing."));
		return;
	}

	if(dao.insert(data)){
		succList.add(translate("Update finished."));
	}
}

//-----------------------------------------------
void delete(AzureDao dao){
	if(dao.delete(paramInt("id"))){
		succList.add(translate("Update finished."));
	}
}

//-----------------------------------------------
void test(AzureDao dao){
	try{
		dao.test(paramInt("id"));
		succList.add(translate("Azure connection succeeded."));
	}
	catch(Exception e){
		errList.add(e.toString());
	}
}

//-----------------------------------------------
void importAzure(AzureDao dao){
	try{
		String res = dao.importAzure(paramInt("id"));
		succList.add(res);
	}
	catch(Exception e){
		errList.add(e.toString());
	}
}
%>
<%
//-----------------------------------------------
// Set permission for this page.
permission.addAdmin();
permission.addSubAdmin();

//Check permission.
if(!checkPermission()){
	return;
}

// Create data access object.
AzureDao dao = new AzureDao();

// Action.
String actionFlag = paramString("actionFlag");
if(actionFlag.equals("insert")){
	insert(dao);
}
if(actionFlag.equals("delete")){
	delete(dao);
}
if(actionFlag.equals("test")){
	test(dao);
}
if(actionFlag.equals("importAzure")){
	importAzure(dao);
}

// Global.
int gCount = dao.selectCount();

// Active tab.
String tabActive0 = "";
String tabActive1 = "";

String showActive0 = "";
String showActive1 = "";

// Reset tabIdx.
int tabIdx = 0;

// If there's an error while creating a new data, stay with the create form.
String g_domain = "";
String g_azClientId = "";
String g_azTenantId = "";
String g_azClientSecret = "";
if(actionFlag.equals("insert") && errList.size() > 0){
	g_domain = paramString("domain");
	g_azClientId = paramString("azClientId");
	g_azTenantId = paramString("azTenantId");
	g_azClientSecret = paramString("azClientSecret");
	tabIdx = 1;
}

if(tabIdx == 0){
	tabActive0 = " active";
	showActive0 = " show active";
}
else if(tabIdx == 1){
	tabActive1 = " active";
	showActive1 = " show active";
}
%>
<!-- Action info -->
<%@include file="include/ab-notify.jsp"%>
<!-- /Action info -->

<!-- Breadcrumb -->
<div class="container-fluid primary" style="margin-top:-5px;">
	<ol class="breadcrumb" style="margin-left:10px; margin-right:10px;">
		<li class="breadcrumb-item"><%= translate("USER")%></li>
		<li class="breadcrumb-item text-info"><%= translate("AZURE DIRECTORY")%></li>
	</ol>
</div>
<!-- /Breadcrumb -->

<!-- Main content -->
<div class="container-fluid">

	<!-- Tab -->
	<div>
		<ul class="nav nav-tabs" style="margin-left:10px; margin-right:10px;">
			<li class="nav-item" onclick="javascript:$('#tabIdx').val(0);">
				<a class="nav-link<%= tabActive0%>" data-toggle="tab" href="#tab0"><%= translate("LIST")%></a>
			</li>
			<li class="nav-item" onclick="javascript:$('#tabIdx').val(1);">
				<a class="nav-link<%= tabActive1%>" data-toggle="tab" href="#tab1"><%= translate("CREATE")%></a>
			</li>
		</ul>
	</div>
	<!-- Tab -->

	<!-- Form -->
	<form action="<%= getPageName()%>" method="post">
		<input type="hidden" name="actionFlag" value="insert">
		<input type="hidden" id="tabIdx" name="tabIdx" value="<%= tabIdx%>">

		<!-- Tab content -->
		<div id="myTabContent" class="tab-content">

			<!-- List -->
			<div class="tab-pane <%= showActive0%>" id="tab0">
				<div id="listDiv" class="container-fluid" style="display: none;">
					<table id="list" class="cell-border hover" style="width:100%">
						<thead>
							<tr>
								<th><%= translate("Domain")%></th>
								<th><%= translate("Application ID")%></th>
								<th><%= translate("Directory ID")%></th>
								<th><%= translate("Client Secret Value")%></th>
								<th><%= translate("Auto-sync")%></th>
								<th></th>
							</tr>
						</thead>
						<tbody>
<%
List<LdapData> dataList = dao.selectList();
for(int i = 0; i < dataList.size(); i++){
	AzureData data = (AzureData)dataList.get(i);
%>
							<tr>
								<td><%= data.domain%></td>
								<td><%= data.azClientId%></td>
								<td><%= data.azTenantId%></td>
								<td><%= data.azClientSecret.replaceAll(".", "*")%></td>
								<td><%= getLdapPeriodStr(data.period)%></td>
								<td>
									<i class="fa fa-pencil-square pointer-cursor" title="<%= translate("Edit")%>" onclick="javascript:goEdit(<%= data.id%>)"></i>&nbsp;
									<i class="fa fa-trash pointer-cursor" title="<%= translate("Delete")%>" onclick="javascript:actionDelete(<%= data.id%>, '<%= data.domain%>')"></i>
									<i class="fa fa-plug pointer-cursor" title="<%= translate("Test")%>" onclick="javascript:actionTest('<%= data.id%>')"></i>&nbsp;
									<i class="fa fa-user-plus pointer-cursor" title="<%= translate("Import")%>" onclick="javascript:actionImport('<%= data.id%>')"></i>&nbsp;
								</td>
							</tr>
<%}%> 
						</tbody>
					</table>
				</div>
			</div>
			<!-- /List -->

			<!-- CREATE -->
			<div class="tab-pane fade<%= showActive1%>" id="tab1">
				<div class="card bg-light m-2 expand-lg">
					<div class="card-body">
						<fieldset>
							<div class="form-group col-lg-8 text-secondary">
								<%= translate("You can import users and groups from Azure Active Directory.", 1000)%>
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label"><%= translate("Domain")%></label>
								<input type="text" class="form-control" id="domain" name="domain" value="<%= g_domain%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">
									<%= translate("Application ID")%>
								</label>
								<input type="text" class="form-control" id="azClientId" name="azClientId" value="<%= g_azClientId%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">
									<%= translate("Directory ID")%>
								</label>
								<input type="text" class="form-control" id="azTenantId" name="azTenantId" value="<%= g_azTenantId%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label"><%= translate("Client Secret Value")%></label>
								<input type="text" class="form-control" id="azClientSecret" name="azClientSecret" value="<%= g_azClientSecret%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label"><%= translate("Auto-sync")%></label>
								<select class="form-control" id="period" name="period">
<%
Map<Integer, String> periodMap = getLdapPeriodMap();
for(Map.Entry<Integer, String> entry : periodMap.entrySet()){
	Integer key = entry.getKey();
	String val = entry.getValue();

	printf("<option value='%s'>%s</option>", key, translate(val));
}
%>
								</select>
							</div>
							<div class="form-group col-lg-8">
								<button type="submit" class="btn btn-primary"><%= translate("SUBMIT")%></button>
							</div>
						</fieldset>
					</div>
				</div>
			</div>
			<!-- /CREATE -->

		</div>
		<!-- Tab content -->

	</form>
	<!-- /Form -->

</div>
<!-- /Main content -->

<!-- goForm -->
<form action="<%= getPageName()%>" name="goForm" method="get">
<input type="hidden" name="actionFlag" value="">
<input type="hidden" name="id" value="">
</form>
<!-- /goForm -->

<%@include file="include/footer.jsp"%>

<script>
//-----------------------------------------------
$(document).ready(function(){
	$("#list").DataTable({
		"bFilter" : false,
		"paging" : false,
		"ordering" : false,
		"info" : true,
		"autoWidth" : false,
		"columnDefs": [{
			"targets": 5,
			"width": "80"
		}],
		"initComplete": function(settings, json){
			$("#listDiv").show();
		},
		language : langMulti,
	});
});

//-----------------------------------------------
function actionDelete(id, domain){
	if(!confirm('<%= translate("Deleting Azure Active Directory setup")%> : ' + domain
		+ '\n<%= translate("All the users and groups associated to the domain will be lost.")%>')){

		return;
	}

	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "delete";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
function goEdit(id){
	var form = document.goForm;
	form.action = "user,azure_edit.jsp";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
function actionTest(id){
	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "test";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
function actionImport(id){
	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "importAzure";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
// Prevent submit again.
if(window.history.replaceState){
	window.history.replaceState(null, null, window.location.href);
}
</script>
